@@ -27,7 +27,8 @@ class ElastalertWebhook(WebhookBase):
             attributes = {}
             attributes['potentialImpact']=payload.get('potentialImpact','N/A')
             attributes['remedy']=payload.get('remedy','N/A')
-            attributes['rawData']=str(payload)
+            attributes['payload']=str(payload)
+            attributes['timestampReceived']=payload.get('@timestamp','N/A')
             createTime = payload.get('@timestamp','N/A')
             try:
                 origin = payload['kubernetes']['host']
